/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.sourceforge.basher.impl;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

import net.sourceforge.basher.Task;

/**
 * @author Johan Lindquist
 * @version 1.0
 */
public class TaskInfo
{
    private Task _task;
    private Class _clazz;
    private Object _instance;

    private List<Task> _followers = new ArrayList<Task>();

    public Task getTask()
    {
        return _task;
    }

    public void setTask(final Task task)
    {
        _task = task;
    }

    public Object getInstance()
    {
        return _instance;
    }

    public void setInstance( final Object instance )
    {
        _instance = instance;
    }

    public Class getClazz()
    {
        return _clazz;
    }

    public void setClazz( final Class clazz )
    {
        _clazz = clazz;
    }

    public void addFollower(final Task task)
    {
        _followers.add(task);
    }

    public List<Task> getFollowers()
    {
        return Collections.unmodifiableList(_followers);
    }

    public void setFollowers(final List<Task> followers)
    {
        _followers = followers;
    }

    @Override
    public String toString()
    {
        return "TaskInfo{" +
                "_task=" + _task +
                ", _clazz=" + _clazz +
                ", _instance=" + _instance +
                ", _followers=" + _followers +
                '}';
    }

    @Override
    public boolean equals( final Object o )
    {
        if ( this == o )
        {
            return true;
        }
        if ( o == null || getClass() != o.getClass() )
        {
            return false;
        }

        final TaskInfo taskInfo = ( TaskInfo ) o;

        if ( _clazz != null ? !_clazz.equals( taskInfo._clazz ) : taskInfo._clazz != null )
        {
            return false;
        }
        if ( _followers != null ? !_followers.equals( taskInfo._followers ) : taskInfo._followers != null )
        {
            return false;
        }
        if ( _instance != null ? !_instance.equals( taskInfo._instance ) : taskInfo._instance != null )
        {
            return false;
        }
        if ( _task != null ? !_task.equals( taskInfo._task ) : taskInfo._task != null )
        {
            return false;
        }

        return true;
    }

    @Override
    public int hashCode()
    {
        int result = _task != null ? _task.hashCode() : 0;
        result = 31 * result + ( _clazz != null ? _clazz.hashCode() : 0 );
        result = 31 * result + ( _instance != null ? _instance.hashCode() : 0 );
        result = 31 * result + ( _followers != null ? _followers.hashCode() : 0 );
        return result;
    }
}
