/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.sourceforge.basher.internal;

/**
 * Defines time based operations.  Allows operations for determining run-time since initialization.
 *
 * @author Johan Lindquist
 * @version 1.0
 */
public interface TimeSource
{
    /**
     * Returns the elapsed time of the running system.  Measured in milliseconds.
     *
     * @return The elapsed time since start-up.
     */
    public long getElapsedTime();

    /**
     * Returns the time the system was started.  Measured in milliseconds since Midnight 1st January 1970.
     *
     * @return The start time.
     */
    public long getStartTime();

    /**
     * Returns the current time in the system. Measured in milliseconds since Midnight 1st January 1970.
     *
     * @return The current time.
     */
    public long getCurrentTime();

    /**
     * Resets the internal time.
     */
    public void reset();

    /** Produces the current nanontime.  See {@link java.lang.System#nanoTime()} for more information 
     *
     * @return
     */
    public long getNanoTime();

}
