package net.sourceforge.basher.internal.impl;

import java.util.List;
import java.util.ArrayList;

import net.sourceforge.basher.tasks.AbstractTask;
import net.sourceforge.basher.Phase;

/** Empty task extending the <code>AbstractTask</code> class.  This class is used if the <code>TaskManager</code> receives
 * a class (as a task) which neither extends <code>AbstractTask</code> nor implements <code>Task</code> and is declared
 * final.  The task will be wrapped by this class and calls to the task are proxied.
 *
 * @author Johan Lindquist
 * @version $Revision$
 */
public abstract class DecoratedTask extends AbstractTask
{
    private String _name = this.getClass().getName();
    private List<Phase> _applicablePhases = new ArrayList<Phase>();
    private boolean _timed;
    private int _interval;

    public boolean isTimed()
    {
        return _timed;
    }

    public void setTimed( final boolean timed )
    {
        _timed = timed;
    }

    public int getInterval()
    {
        return _interval;
    }

    public void setInterval( final int interval )
    {
        _interval = interval;
    }

    public String getName()
    {
        return _name;
    }

    public void setName(final String name)
    {
        _name = name;
    }

    @Override
    public List<Phase> applicablePhases()
    {
        return _applicablePhases;
    }

    public void addPhase(final Phase phase)
    {
        if (!_applicablePhases.contains(phase))
        {
            _applicablePhases.add(phase);
        }
    }

    public void removePhase(final Phase phase)
    {
        _applicablePhases.remove(phase);
    }

    public void clearPhases()
    {
        _applicablePhases.clear();
    }

    @Override
    public String toString()
    {
        return "DecoratedTask{" +
                "_name='" + _name + '\'' +
                ", _applicablePhases=" + _applicablePhases +
                ", _timed=" + _timed +
                ", _interval=" + _interval +
                "} " + super.toString();
    }

    @Override
    public boolean equals( final Object o )
    {
        if ( this == o )
        {
            return true;
        }
        if ( o == null || getClass() != o.getClass() )
        {
            return false;
        }
        if ( !super.equals( o ) )
        {
            return false;
        }

        final DecoratedTask that = ( DecoratedTask ) o;

        if ( _interval != that._interval )
        {
            return false;
        }
        if ( _timed != that._timed )
        {
            return false;
        }
        if ( _applicablePhases != null ? !_applicablePhases.equals( that._applicablePhases ) : that._applicablePhases != null )
        {
            return false;
        }
        if ( _name != null ? !_name.equals( that._name ) : that._name != null )
        {
            return false;
        }

        return true;
    }

    @Override
    public int hashCode()
    {
        int result = super.hashCode();
        result = 31 * result + ( _name != null ? _name.hashCode() : 0 );
        result = 31 * result + ( _applicablePhases != null ? _applicablePhases.hashCode() : 0 );
        result = 31 * result + ( _timed ? 1 : 0 );
        result = 31 * result + _interval;
        return result;
    }
}
